@@ -3,73 +3,25 @@
 # abs.sh
 # This file is part of Yaourt (http://archlinux.fr/yaourt-en)
 
-RSYNCCMD=$(type -p rsync 2> /dev/null)
-RSYNCOPT="-mrtv --no-motd --no-p --no-o --no-g"
-
-ABSCONF=0
-
 load_lib alpm_query
 load_lib pkgbuild
 
-# source abs configuration
-source_abs_conf() {
-	((ABSCONF)) && return || ABSCONF=1
-	local vars=()
-	local abs_conf
-	[[ ! $SYNCSERVER ]] && vars+=(SYNCSERVER)
-	[[ ! $REPOS ]] && vars+=(REPOS)
-	if [[ $vars ]]; then
-		abs_conf=$(
-			[[ -r "/etc/abs.conf" ]] &&
-			    source  "/etc/abs.conf" > /dev/null
-			[[ -r ~/.abs.conf ]] &&
-			    source  ~/.abs.conf > /dev/null
-			declare -p ${vars[*]} 2>/dev/null | tr '\n' ';'
-		)
-		[[ ! $abs_conf ]] && return
-		# Change vars names because "declare" create a local var
-		abs_conf=${abs_conf//SYNCSERVER/_SYNCSERVER}
-		abs_conf=${abs_conf//REPOS/_REPOS}
-		eval "$abs_conf"
-		SYNCSERVER=${SYNCSERVER:-$_SYNCSERVER}
-		[[ ! $REPOS ]] && REPOS=(${_REPOS[@]})
-	fi
-}
-
 # Get sources in current dir
 # Usage abs_get_pkgbuild ($repo/$pkg[,$arch,[$pkgbase]])
 abs_get_pkgbuild() {
-	source_abs_conf
-	local repo=${1%/*} pkg=${1#*/} arch=$2 pkgbase=$3 pkgver=
+	local repo=${1%/*} pkg=${1#*/} arch=$2 pkgbase=$3 pkgver= url=
+
 	if [[ ! $arch || ! $pkgbase ]]; then
 		read arch pkgver < <(pkgquery -1Sif '%a %v' "$repo/$pkg")
 		pkgbase=$(get_pkgbase $pkg $repo $pkgver)
 	fi
-	if ((USE_GIT)) && [[ " ${REPOS[*]} " =~ " $repo " ]]; then
-		local url
-		if [[ $repo = "core" || $repo = "extra" ]]; then
-			url="https://projects.archlinux.org/svntogit/packages.git/snapshot/packages/$pkgbase.tar.gz"
-		else
-			url="https://projects.archlinux.org/svntogit/community.git/snapshot/community-packages/$pkgbase.tar.gz"
-		fi
-		curl_fetch -L -f "$url" -o - | bsdtar --strip-components 3 --include="*/$pkgbase/trunk/" -xvf -
+
+	if [[ $repo = "core" || $repo = "extra" || $repo = "testing" ]]; then
+		url="https://git.archlinux.org/svntogit/packages.git/snapshot/packages/$pkgbase.tar.gz"
 	else
-		if [[ $RSYNCCMD && $SYNCSERVER && " ${REPOS[*]} " =~ " $repo " ]]; then
-			$RSYNCCMD $RSYNCOPT "$SYNCSERVER::abs/$arch/$repo/$pkgbase/" . && return 0
-		fi
-		# TODO: store abs archive somewhere else.
-		local abs_tar="$YAOURTTMPDIR/$repo.abs.tar.gz"
-		local abs_url
-		local repo_date=$(stat -c "%Z" "${P[dbpath]}/sync/$repo.db")
-		local abs_repo_date=$(stat -c "%Z" "$abs_tar" 2> /dev/null)
-		if [[ ! $abs_repo_date ]] || (( ${abs_repo_date%.*} < ${repo_date%.*} )); then
-			abs_url=$(pkgquery -1Sif "%u" "$repo/$pkg")
-			abs_url="${abs_url%/*}/$repo.abs.tar.gz"
-			msg "$repo/$pkgbase: $(gettext 'Download abs archive')"
-			curl_fetch -L -f -# "$abs_url" -o "$abs_tar" || return 1
-		fi
-		bsdtar --strip-components 2 -xvf "$abs_tar" "$repo/$pkgbase"
+		url="https://git.archlinux.org/svntogit/community.git/snapshot/community-packages/$pkgbase.tar.gz"
 	fi
+	curl_fetch -L -f "$url" -o - | bsdtar --strip-components 3 --include="*/$pkgbase/trunk/" -xvf -
 }
 
 # Build from abs or aur
@@ -258,8 +210,8 @@ display_update() {
 			   SP_ARG="" sync_packages "$YAOURTTMPDIR/sysuplist"
 			   return 2
 			   ;;
-			N) return 1;;
-			*) break;;
+			Y) break;;
+			*) return 1;;
 		esac
 	done
 }
@@ -454,5 +406,4 @@ upgrade_devel_package() {
 	show_targets 'Targets' "${devel_pkgs[@]}" && build_pkg "${devel_pkgs[@]}"
 }
 
-
 # vim: set ts=4 sw=4 noet:
