@@ -28,9 +28,9 @@ analyse_status_list() {
 			msg "$(gettext 'Packages no longer required by any installed package:')"
 			echo_wrap 4 "$neworphans"
 		fi
-	fi	
+	fi
 	# Test local database
-	if [[ ! "$NO_TESTDB" ]]; then testdb; fi
+	((NO_TESTDB)) || $PACMAN -Dk
 	if ((AUTOSAVEBACKUPFILE)) && ! \
 		diff "$Y_PKG_INSTALLED" <(pkgquery -Qf '%n %v' --sort n) &> /dev/null; then
 		# save original of backup files (pacnew/pacsave)
@@ -39,4 +39,4 @@ analyse_status_list() {
 	fi
 }
 
-# vim: set ts=4 sw=4 noet: 
+# vim: set ts=4 sw=4 noet:
