@@ -265,7 +265,7 @@ build_package() {
 	# install deps from abs (build or download) as depends
 	if [[ $PKGBUILD_DEPS ]]; then
 		msg $(_gettext 'Install or build missing dependencies for %s:' "$pkgbase")
-		if ! SP_ARG="--asdeps" sync_packages "${PKGBUILD_DEPS[@]}"; then
+		if ! SP_ARG="--asdeps" INSTALL_FLAG=1 sync_packages "${PKGBUILD_DEPS[@]}"; then
 			local _deps_left=( $(pacman_parse -T "${PKGBUILD_DEPS[@]}") )
 			local _deps_installed=()
 			for _deps in "${PKGBUILD_DEPS[@]}"; do
@@ -340,8 +340,8 @@ install_package() {
 				fi
 				echo
 				;;
-			N)	failed=1; break;;
-			*)	break;;
+			Y)	break;;
+			*)	failed=1; break;;
 		esac
 	done
 	(( ! failed )) &&
@@ -366,7 +366,8 @@ init_build_dir() {
 }
 
 custom_pkg() {
-	(( CUSTOMIZEPKGINSTALLED )) && [[ -f "/etc/customizepkg.d/$1" ]] && return 0
+	LOCALCONFIGDIR=${CUSTOMIZEPKG_CONFIG:-${HOME}/.customizepkg}
+	(( CUSTOMIZEPKGINSTALLED )) && [[ -f "/etc/customizepkg.d/$1" || -f "$LOCALCONFIGDIR/$1" ]] && return 0
 	return 1
 }
 
@@ -374,11 +375,11 @@ custom_pkg() {
 # on success, call install_package
 # Usage: package_loop ($pkgname, $trust)
 #   $pkgname: name of package
-#	$trust: 1: default answer for editing: Y (for abs)
+#	$trust: 1: default answer for editing: N (for abs)
 package_loop() {
 	local pl_pkgname=$1
 	local trust=${2:-0}
-	local default_answer=1
+	local answer default_answer=1
 	local ret=0 failed=0
 	declare -a PKGBUILD_DEPS PKGBUILD_DEPS_INSTALLED \
 	           PKGBUILD_CONFLICTS PKGBUILD_VARS
@@ -396,16 +397,17 @@ package_loop() {
 		case "$ret" in
 			0|2) break ;;
 			1)	prompt "$(_gettext 'Restart building %s ? ' "$pl_pkgname")$(yes_no 2)"
-				builduseragrees "YN" "N" && { failed=1; break; }
+				answer=$(builduserinput "YN" "N")
+				[[ $answer = "Y" ]] || { failed=1; break; }
 				;;
 			*) return 99 ;; # should never execute
 		esac
 	done
 	(( ! ret )) && (( ! failed )) &&
-	  ( [[ $MAJOR == "pkgbuild" ]] && (( YPKGBUILD_INSTALL )) || ! [[ $MAJOR == "pkgbuild" ]] ) &&
+	  ( [[ $MAJOR == "pkgbuild" ]] && (( INSTALL_FLAG )) || ! [[ $MAJOR == "pkgbuild" ]] ) &&
 	    { install_package || failed=1; }
 
-	[[ $MAJOR == "pkgbuild" ]] && (( ! YPKGBUILD_INSTALL )) && cp -v "$YPKGDEST/"*.pkg.* $YPKGBUILDDIR
+	[[ $MAJOR == "pkgbuild" ]] && (( ! INSTALL_FLAG )) && cp -v "$YPKGDEST/"*.pkg.* "$YPKGBUILDDIR"
 	rm -r "$YPKGDEST"
 	return $failed
 }
@@ -455,8 +457,11 @@ get_pkgbuild() {
 			local newdir=$(mktemp --dry-run --tmpdir="." "$pkgdir.XXX")
 			prompt2 "$(_gettext '%s directory already exist. [R]eplace, [C]hange to %s, [S]kip ?' "$pkgdir" "$newdir")"
 			local answer=$(userinput "RCS" "R")
-			[[ $answer = "S" ]] && continue
-			[[ $answer = "C" ]] && pkgdir=$newdir
+			case $answer in
+				R) :;;
+				C) pkgdir=$newdir;;
+				*) continue;;
+			esac
 		fi
 		mkdir -p "$pkgdir"
 		cd "$pkgdir" || continue
@@ -484,8 +489,9 @@ get_pkgbuild() {
 }
 
 
-# Call package_pkgbuild_only for building a PKGBUILD in the current directory until success or abort
-# on success, call install_package, if YPKGBUILD_INSTALL was specified with -i
+# Call package_pkgbuild_only for building a PKGBUILD in the current directory
+# until success or abort. On success, call install_package, if INSTALL_FLAG was
+# specified with -i
 # Usage: package_pkgbuild_only ($pkgname)
 #   $pkgname: name of package
 package_pkgbuild_only() {
@@ -497,11 +503,12 @@ package_pkgbuild_only() {
 
 	# Glob files from YPKGBUILDDIR and copy them to $YTMPDIR
 	local YFILES=("$YPKGBUILDDIR/PKGBUILD")
-	YFILES+=($(find "$YPKGBUILDDIR/"*.install -type f 2>/dev/null))
-	YFILES+=($(find "$YPKGBUILDDIR/"*.patch   -type f 2>/dev/null))
+	for file in "$YPKGBUILDDIR/"*.{install,patch}; do
+		[[ -f $file ]] && YFILES+=("$file")
+	done
 
 	msg $(_gettext "Copying files from %s to build directory..." "$YPKGBUILDDIR")
-	cp -v ${YFILES[@]} "$YTMPDIR"
+	cp -v "${YFILES[@]}" "$YTMPDIR"
 	echo
 
 	package_loop "$YPKG" 1 || manage_error "$YPKG" ||
