@@ -243,10 +243,6 @@ DEVEL=0
 FORCE=0
 SUDONOVERIF=0
 NO_TESTDB=0
-# ABS
-USE_GIT=0
-REPOS=()
-SYNCSERVER=""
 # AUR
 AURURL='https://aur.archlinux.org'
 AURCOMMENT=5
